@@ -38,6 +38,18 @@ config_dir = user_config_dir(__name__.split(".")[0], False)
 logger = logging.getLogger("SensiML")
 
 
+def project_set(func):
+    def wrapper(*args, **kwargs):
+        self = args[0]
+        if self._project is None:
+            print("Project must be set.")
+            return None
+        else:
+            return func(*args, **kwargs)
+
+    return wrapper
+
+
 def print_list(func):
     """This is a wrapper for printing out lists of objects stored in SensiML Cloud"""
 
@@ -268,25 +280,25 @@ class Client(object):
         return segmenters.to_dataframe()
 
     def get_knowledgepack(self, uuid):
-        """retrieve knowledgepack by uuid from the server associated with current project
+        """Retrieve a Knowledge Pack by uuid from the server associated with current project
 
         Args:
-            uuid (str): unique identifier for knowledgepack
+            uuid (str): unique identifier for Knowledge Pack
 
         Returns:
-            TYPE: a knowledgepack object
+            TYPE: a Knowledge Pack object
         """
 
         return get_knowledgepack(uuid, self._connection)
 
     def delete_knowledgepack(self, uuid):
-        """delete knowledgepack by uuid from the server associated with current project
+        """Delete Knowledge Pack by uuid from the server associated with current project
 
         Args:
-            uuid (str): unique identifier for knowledgepack
+            uuid (str): unique identifier for Knowledge Pack
 
         Returns:
-            TYPE: a knowledgepack object
+            TYPE: a Knowledge Pack object
         """
 
         return delete_knowledgepack(uuid, self._connection)
@@ -297,10 +309,10 @@ class Client(object):
         return self._project
 
     def get_featurefile(self, uuid):
-        """Get a featurefile by uuid
+        """Get a FeatureFile by uuid
 
         Args:
-            get_objects (bool, False): Also return the featurefile objects.
+            get_objects (bool, False): Also return the FeatureFile objects.
 
         """
         if self._project is None:
@@ -312,7 +324,7 @@ class Client(object):
         """Get a datafile by uuid
 
         Args:
-            get_objects (bool, False): Also return the featurefile objects.
+            get_objects (bool, False): Also return the datafile objects.
 
         """
         if self._project is None:
@@ -358,6 +370,11 @@ class Client(object):
 
         return self._project._captures.build_capture_list()
 
+    @project_set
+    def get_captures(self):
+        """Returns the capture set object"""
+        return self._project._captures.build_capture_list()
+
     @print_list
     def list_capture_configurations(self, get_objects=False):
         """List all captures for the active project
@@ -371,6 +388,10 @@ class Client(object):
 
         return self._project._capture_configurations.build_capture_list()
 
+    def capture_configurations(self):
+        """Returns the capture set object"""
+        return self._project._capture_configurations.build_capture_list()
+
     @print_list
     def list_sandboxes(self, get_objects=False):
         """List all sandboxes for the active project.
@@ -384,6 +405,11 @@ class Client(object):
             raise Exception("Project must be set to perform this action.")
         return self._project._sandboxes.build_sandbox_list()
 
+    @project_set
+    def get_pipelines(self):
+        """Returns the pipeline set dictionary"""
+        return self._project._sandboxes.build_sandbox_list()
+
     @print_list
     def list_pipelines(self, get_objects=False):
         """List all pipelines for the active project.
@@ -408,6 +434,11 @@ class Client(object):
             raise Exception("Project must be set to perform this action.")
         return self._project._queries.build_query_list()
 
+    @project_set
+    def get_queries(self):
+        """Returns the query set dictionary"""
+        return self._project._queries.build_query_list()
+
     @project.setter
     def project(self, name):
         self._project = self.projects.get_or_create_project(name)
@@ -426,16 +457,16 @@ class Client(object):
 
     def create_query(
         self,
-        name,
-        columns=[],
-        metadata_columns=[],
-        metadata_filter="",
+        name: str,
+        columns: list = [],
+        metadata_columns: list = [],
+        metadata_filter: str = "",
         segmenter=None,
-        label_column="",
+        label_column: str = "",
         combine_labels=None,
-        force=False,
+        force: bool = False,
         renderer=None,
-        capture_configurations="",
+        capture_configurations: str = "",
     ):
         """Create a query to use as input data in a pipeline.
 
@@ -516,8 +547,23 @@ class Client(object):
 
         return self.project.queries.get_query_by_name(name)
 
-    def upload_data_file(self, name, path, force=False, is_features=False):
-        """Upload data source from local CSV file"""
+    def upload_data_file(
+        self, name: str, path: str, force: bool = False, is_features: bool = False
+    ):
+        """Upload a .CSV file as either a FeatureFile or DataFile to the server.
+
+        FeatureFiles are a collection of feature vectors and can be used in any step after the feature generation step
+        DataFiles include sensor data and metadata and are used in any step prior to feature generation
+
+        Args:
+            name (str): Name of the file when it is uploaded
+            path (str): The path to the file to upload
+            force (bool, optional): Will overwrite if already exists. Defaults to False.
+            is_features (bool, optional): If True, will upload as a feature file, if False will upload as a DataFile. Defaults to False.
+
+        Returns:
+            response: The response as a request object
+        """
         logger.debug("set_feature_file:" + name + ":" + path)
         print('Uploading file "{}" to SensiML Cloud.'.format(name))
         if name[-4:] != ".csv":
@@ -542,8 +588,28 @@ class Client(object):
         else:
             return feature_file.update()
 
-    def upload_dataframe(self, name, dataframe, force=False, is_features=False):
-        """Set data source from a pandas DataFrame."""
+    def upload_dataframe(
+        self,
+        name: str,
+        dataframe: DataFrame,
+        force: bool = False,
+        is_features: bool = False,
+    ):
+        """Upload a pandas DataFrame as either a FeatureFile or DataFile to the server.
+
+        FeatureFiles are a collection of feature vectors and can be used in any step after the feature generation step
+        DataFiles include sensor data and metadata and are used in any step prior to feature generation
+
+        Args:
+            name (str): Name of the file when it is uploaded
+            dataframe (DatFrame): Pandas DataFrame
+            force (bool, optional): Will overwrite if already exists. Defaults to False.
+            is_features (bool, optional): If True, will upload as a feature file, if False will upload as a DataFile. Defaults to False.
+
+        Returns:
+            response: The response as a request object
+        """
+
         logger.debug("set_data:" + name)
 
         with NamedTemporaryFile(delete=False) as temp:
@@ -557,6 +623,58 @@ class Client(object):
 
         return result
 
+    def upload_sensor_dataframe(self, name, dataframe, force=False):
+        """Upload a pandas DataFrame as a DataFile to the server.
+
+        DataFiles include sensor data and metadata and can be used in any any step prior to feature generation
+
+        Args:
+            name (str): Name of the file when it is uploaded
+            dataframe (DatFrame): Pandas DataFrame
+            force (bool, optional): Will overwrite if already exists. Defaults to False.
+
+        Returns:
+            response: The response as a request object
+        """
+        logger.debug("set_data:" + name)
+
+        with NamedTemporaryFile(delete=False) as temp:
+            dataframe.to_csv(temp.name, index=False)
+            logger.debug("set_dataframe:" + name + ":" + temp.name)
+            result = self.upload_data_file(
+                name, temp.name, force=force, is_features=False
+            )
+
+        os.remove(temp.name)
+
+        return result
+
+    def upload_feature_dataframe(self, name, dataframe, force=False):
+        """Upload a pandas DataFrame as a FeatureFile to the server.
+
+        FeatureFiles are a collection of feature vectors and can be used in any step after the feature generation step
+
+        Args:
+            name (str): Name of the file when it is uploaded
+            dataframe (DatFrame): Pandas DataFrame
+            force (bool, optional): Will overwrite if already exists. Defaults to False.
+
+        Returns:
+            response: The response as a request object
+        """
+        logger.debug("set_data:" + name)
+
+        with NamedTemporaryFile(delete=False) as temp:
+            dataframe.to_csv(temp.name, index=False)
+            logger.debug("set_dataframe:" + name + ":" + temp.name)
+            result = self.upload_data_file(
+                name, temp.name, force=force, is_features=True
+            )
+
+        os.remove(temp.name)
+
+        return result
+
     def clear_session_cache(self):
         for _, _, filenames in os.walk(config_dir):
             for filename in filenames:
