@@ -2,34 +2,38 @@ try:
     from http.cookiejar import CookiePolicy
 except ImportError:
     from cookielib import CookiePolicy
+
+import errno
+import json as JSON
+import logging
 import os
 import re
-import json as JSON
-import requests_oauthlib
+import warnings
+from functools import partial
+from getpass import getpass
+from time import sleep
+from uuid import uuid4
+
 import requests
-from requests import Response
+import requests_oauthlib
+from appdirs import user_config_dir
 from oauthlib.oauth2 import (
-    LegacyApplicationClient,
     InvalidGrantError,
+    LegacyApplicationClient,
     MissingTokenError,
     TokenExpiredError,
 )
-from requests_oauthlib import OAuth2Session, OAuth2
-from getpass import getpass
-from appdirs import user_config_dir
-import errno
-from uuid import uuid4
-from time import sleep
-import logging
-import warnings
-from functools import partial
-from .connection_config import ConnectionConfig
+from requests import Response
+from requests_oauthlib import OAuth2, OAuth2Session
 from six.moves import input
 
+from .connection_config import ConnectionConfig
+
 try:
     import configparser as ConfigParser
 except:
     import ConfigParser
+
 from .errors import *
 
 logger = logging.getLogger(__name__)
