@@ -18,6 +18,7 @@ from sensiml.datamanager.confusion_matrix import (
 )
 from sensiml.datamanager.deviceconfig import DeviceConfig
 from sensiml.datamanager.featurefile import FeatureFile
+from sensiml.method_calls.functioncall import FunctionCall
 from sensiml.visualize.knowledgepack_visualize_mixin import VisualizeMixin
 
 logger = logging.getLogger(__name__)
@@ -331,7 +332,7 @@ class KnowledgePack(VisualizeMixin):
         elif datafile:
             if datafile[-4:] != ".csv":
                 datafile = "{}.csv".format(datafile)
-            data_for_recognition = {"featurefile": datafile}
+            data_for_recognition = {"datafile": datafile}
         else:
             print(
                 "You must select a capture, featurefile  or datafile to run recognition against."
