@@ -1,10 +1,14 @@
 from sensiml.dclproj.dclproj import DCLProject
 from sensiml.dclproj.csv_to_dcli import to_dcli
-from sensiml.dclproj.datasegments import segment_list_to_datasegments
+from sensiml.dclproj.datasegments import (
+    segment_list_to_datasegments,
+    audacity_to_datasegments,
+)
 
 
 __all__ = [
     "DCLProject",
     "to_dcli",
     "segment_list_to_datasegments",
+    "audacity_to_datasegments",
 ]
