@@ -8,7 +8,7 @@ class CaptureFileCall(PipelineStep):
         super(CaptureFileCall, self).__init__(name=name, step_type="CaptureFileCall")
         self.name = name
         self._data_columns = None
-        self._group_columns = ["Subject"]
+        self._group_columns = None
 
     @property
     def name(self):
@@ -42,7 +42,9 @@ class CaptureFileCall(PipelineStep):
 
     @group_columns.setter
     def group_columns(self, value):
-        print("Capture files default to Subject.")
+        print(
+            "Capture files do not have group columns, use a data file if you need group columns."
+        )
 
     def _to_dict(self):
         capturefile_dict = {}
